@@ -20,6 +20,8 @@
 #'   hence you cannot customize these arguments).
 #' @export
 serve_site = function(...) {
+  op = options(servr.daemon = getOption('servr.daemon', interactive()))
+  on.exit(options(op), add = TRUE)
   serve = switch(
     generator(), hugo = serve_it(),
     jekyll = serve_it(
@@ -164,6 +166,6 @@ stop_server = function() {
 }
 
 get_config2 = function(key, default) {
-  res = yaml::yaml.load_file('_config.yml')
+  res = yaml_load_file('_config.yml')
   res[[key]] %n% default
 }
